@@ -199,12 +199,6 @@ class OSMRelation:
 
         self.color = relation.tags.get("colour", generate_random_color("HEX")) if not color else color
 
-        for w in self.ways:
-            lon, lat = [n.lon for n in w.nodes], [n.lat for n in w.nodes]
-            x, y = config.proj(lon, lat)
-
-            pass
-
     def to_ipyleaflef(self) -> List[list]:
         """
 
@@ -220,7 +214,7 @@ class OSMRelation:
 
 
 class OSMRailwayLine(OSMRelation):
-    def __init__(self, relation: overpy.Relation, ways: List[overpy.Way] = None):
+    def __init__(self, relation: overpy.Relation, ways: List[overpy.Way] = None, color=None):
         """ Class representing a railway line
 
         See https://wiki.openstreetmap.org/wiki/Tag:railway%3Drail
@@ -236,7 +230,7 @@ class OSMRailwayLine(OSMRelation):
         members: list
             list of nodes and ways associated with the railway line
         """
-        super().__init__(relation=relation, ways=ways)
+        super(OSMRailwayLine, self).__init__(relation=relation, ways=ways, color=color)
 
         self.tags = relation.tags
 
